@@ -106,18 +106,11 @@ pub fn parse(doc: &str) -> Result<Dom, String> {
     let mut dom_vec = create_dom_vec(&mut input)?;
     //debug_print_dom_vec(&dom_vec);
 
-    let mut root_dom = create_root_dom();
+    let mut root_dom = Dom::new_root();
     create_dom_tree(&mut dom_vec, &mut root_dom);
     Ok(root_dom)
 }
 
-fn create_root_dom() -> Dom {
-    let tag = Tag::new(String::from("root"));
-    let mut dom = Dom::new(DomType::Tag);
-    dom.set_tag(tag);
-    dom
-}
-
 /// Returns the value of the tag's attribute.
 ///
 /// State to receive:
@@ -495,7 +488,7 @@ fn search_terminator(dom_vec: &mut Vec<Dom>, starter: &Tag) -> Option<usize> {
 }
 
 /// If the tag is not terminated, add it to the child, otherwise add it to the child.
-pub fn create_dom_tree(dom_vec: &mut Vec<Dom>, parent: &mut Dom) {
+fn create_dom_tree(dom_vec: &mut Vec<Dom>, parent: &mut Dom) {
     while !dom_vec.is_empty() {
         let mut dom = dom_vec.remove(0);
 
